package cn.com.infosec.asn1.isismtt.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERString;
import cn.com.infosec.asn1.isismtt.ISISMTTObjectIdentifiers;
import cn.com.infosec.asn1.x500.DirectoryString;
import java.util.Enumeration;

public class NamingAuthority extends ASN1Encodable {
   public static final DERObjectIdentifier id_isismtt_at_namingAuthorities_RechtWirtschaftSteuern;
   private DERObjectIdentifier namingAuthorityId;
   private String namingAuthorityUrl;
   private DirectoryString namingAuthorityText;

   static {
      id_isismtt_at_namingAuthorities_RechtWirtschaftSteuern = new DERObjectIdentifier(ISISMTTObjectIdentifiers.id_isismtt_at_namingAuthorities + ".1");
   }

   public static NamingAuthority getInstance(Object obj) {
      if (obj != null && !(obj instanceof NamingAuthority)) {
         if (obj instanceof ASN1Sequence) {
            return new NamingAuthority((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (NamingAuthority)obj;
      }
   }

   public static NamingAuthority getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   private NamingAuthority(ASN1Sequence seq) {
      if (seq.size() <= 3) {
         DEREncodable var2;
         Enumeration seq1;
         if ((seq1 = seq.getObjects()).hasMoreElements()) {
            if ((var2 = (DEREncodable)seq1.nextElement()) instanceof DERObjectIdentifier) {
               this.namingAuthorityId = (DERObjectIdentifier)var2;
            } else if (var2 instanceof DERIA5String) {
               this.namingAuthorityUrl = DERIA5String.getInstance(var2).getString();
            } else {
               if (!(var2 instanceof DERString)) {
                  throw new IllegalArgumentException("Bad object encountered: " + var2.getClass());
               }

               this.namingAuthorityText = DirectoryString.getInstance(var2);
            }
         }

         if (seq1.hasMoreElements()) {
            if ((var2 = (DEREncodable)seq1.nextElement()) instanceof DERIA5String) {
               this.namingAuthorityUrl = DERIA5String.getInstance(var2).getString();
            } else {
               if (!(var2 instanceof DERString)) {
                  throw new IllegalArgumentException("Bad object encountered: " + var2.getClass());
               }

               this.namingAuthorityText = DirectoryString.getInstance(var2);
            }
         }

         if (seq1.hasMoreElements()) {
            DEREncodable seq2;
            if (!((seq2 = (DEREncodable)seq1.nextElement()) instanceof DERString)) {
               throw new IllegalArgumentException("Bad object encountered: " + seq2.getClass());
            }

            this.namingAuthorityText = DirectoryString.getInstance(seq2);
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public NamingAuthority(DERObjectIdentifier namingAuthorityId, String namingAuthorityUrl, DirectoryString namingAuthorityText) {
      this.namingAuthorityId = namingAuthorityId;
      this.namingAuthorityUrl = namingAuthorityUrl;
      this.namingAuthorityText = namingAuthorityText;
   }

   public DERObjectIdentifier getNamingAuthorityId() {
      return this.namingAuthorityId;
   }

   public DirectoryString getNamingAuthorityText() {
      return this.namingAuthorityText;
   }

   public String getNamingAuthorityUrl() {
      return this.namingAuthorityUrl;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERObjectIdentifier var2;
      if ((var2 = this.namingAuthorityId) != null) {
         var1.add(var2);
      }

      String var5;
      if ((var5 = this.namingAuthorityUrl) != null) {
         DERIA5String var3;
         var3 = new DERIA5String.<init>(var5, true);
         var1.add(var3);
      }

      DirectoryString var4;
      if ((var4 = this.namingAuthorityText) != null) {
         var1.add(var4);
      }

      return new DERSequence(var1);
   }
}
